# Update Elasticsearch file log4j.jar regarding the vulnerability for CVE-2021-44228

#log4j-1.2-api-2.17.0.jar
#log4j-api-2.17.0.jar
#log4j-core-2.17.0.jar


# include subroutines
. .\scripts\ps\elasticsearch.ps1
. .\scripts\ps\logging.ps1


# check for Constrained Langue mode
if ($ExecutionContext.SessionState.LanguageMode -eq "ConstrainedLanguage") {
    logWrite "ConstrainedLanguage mode detected!"
    logWrite "To continue, you may need to change the environment variable '__PSLockdownPolicy' from 4 to 8."
    logWrite "After the change, close the command prompt window and start again."
    logWrite "If you cannot proceed, contact customer experience."
    break
}

# create the log file
$dateStamp = Get-Date -Format "yyyyMMddhhmm"
$fileName = "\logs\ElasticsearchUpdate_" + $dateStamp + ".log"
$logfile = join-path $PWD $fileName

logWrite "Stopping Elasticsearch Service..."
$result = stopElasticSearchService
if ($result -eq 1) {
    logWrite "Terminating upgrade process. Unable to stop Elasticsearch service."
    break
}

$continueProcess = $true

#files that need to be switched
$listFiles = @(
    "log4j-api-2.*",
    "log4j-1.2-api-2.*",
    "log4j-core-2.*"
    )

for ($i=0; $i -le $listFiles.Length - 1; $i++)  {
    $filename = $listFiles[$i]
    logWrite "Finding the file $filename."
    $result = deleteElasticSearchFile $PWD $filename
    if ($result -eq 1) {
        logWrite "Terminating upgrade process. Unable to delete the file $filename"
        #restart the ES service
        logWrite "Starting Elasticsearch service..."
        $result = startElasticsearch $PWD
        if ($result -eq 1) {
            logWrite "Terminating upgrade process. Unable to start the service."
        }
        #finalize the script process
        $continueProcess = $false
        break
    }
}

if($continueProcess){
    #copy files to lib folder
    logWrite "Updating Elasticsearch jar files..."
    $result = copyElastisearchFile $PWD
    if ($result -eq 1) {
        logWrite "Terminating upgrade process. Unable to update files"
        break
    }

    #start the service
    logWrite "Starting Elasticsearch service..."
    $result = startElasticsearch $PWD
    if ($result -eq 1) {
        logWrite "Terminating upgrade process. Unable to start the service."
        break
    }

    logWrite "Elasticsearch update finished successfully!"
    logWrite ""
}