function getESPathInstalation {
    #get the elasticsearch path
    $ESService = Get-WmiObject win32_service | ? { $_.Name -like 'elastic*' } | select PathName
    if($ESService -eq $null){
        logwrite "Unable to find the Elasticserach service."
        return 1
    }
    $ESPath = $ESService.PathName.Replace("\elasticsearch-service-x64.exe //RS//elasticsearch-service-x64", "")
    return $ESPath.Replace("\bin", "")
}

function stopElasticSearchService {
    try {
        $service = Get-Service -Name Elastic*
        if ($service.Status -ne 'Stopped') {
            $service.Stop()
            $service.WaitForStatus('Stopped', '00:01:00') 
        }
    
        if ($service.Status -ne 'Stopped') {
            return 1
        }

        logWrite "ElasticSearch service stopped"
        return 0
    }
    catch {
        logWrite  $_.Exception.Message
        return 1
    }
}

function deleteElasticSearchFile(
    [string]$rootPath,
    [string]$filename
){
    $path = getESPathInstalation + "\lib"
    $checkpath = Get-ChildItem -Path $path -Filter $filename -Recurse | %{$_.FullName}
    if(!$checkpath)
    {
	    return 1
    }
    
    $exists = Test-Path -Path $checkpath
    if ($exists) {
        try{
            LogWrite "Deleting the $checkpath file."
            Remove-Item -Path $checkpath -Recurse -Force -Confirm:$false
            LogWrite "File deleted successfully."
            return 0
        }
        catch{
           logWrite $_.Exception.Message
        return 1 
        }
    }
    else {
        return 1
    }
}

function copyElastisearchFile (
    [string]$rootPath
) {
    $patchFile = join-path $rootpath "resources"
    
    try {
        $pathES = getESPathInstalation
        $destination = join-path $pathES "\lib"
        $exists = Test-Path -Path $destination
        if ($exists) {
            Get-ChildItem $patchFile -Recurse -file | Copy-Item -Destination $destination -Force
            logWrite "The Elasticsearch *.jar files updated successfully."
            return 0
        }
        else {
            logWrite "The destination: $destination does not exist."
            return 0
        }
    }
    catch {
        $logError = "ERROR: " + $_.Exception.Message
        logWrite $logError
        return 1
    }
}

function startElasticsearch {
    try {
        $service = Get-Service -Name Elastic*
        if ($service.Status -ne 'Running') {
            $service.Start()
            $service.WaitForStatus('Running', '00:01:00') 
        }
        if ($service.Status -ne 'Running') {
            return 1
        }
        logWrite "ElasticSearch service running"
        return 0
    }
    catch {
        logWrite  $_.Exception.Message
        return 1
    }
}